@@ -156,7 +156,7 @@ int ploop_di_add_image(struct ploop_disk_images_data *di, const char *fname,
 		return ret;
 	}
 
-	ploop_log(3, "add snapshot %s", guid);
+	ploop_log(3, "Adding snapshot %s", guid);
 	free(di->top_guid);
 	di->top_guid = top_guid;
 
@@ -223,7 +223,7 @@ void ploop_free_diskdescriptor(struct ploop_disk_images_data *di)
 	free(di);
 }
 
-static int find_image_idx_by_guid(struct ploop_disk_images_data *di, const char *guid)
+int find_image_idx_by_guid(struct ploop_disk_images_data *di, const char *guid)
 {
 	int i;
 
