@@ -115,7 +115,7 @@ void tune_fs(const char *target, const char *device, unsigned long long size_sec
 				size_sec);
 		return;
 	}
-	argv[0] = "/sbin/tune2fs";
+	argv[0] = "tune2fs";
 	argv[1] = "-r";
 	snprintf(buf, sizeof(buf), "%llu", reserved_blocks);
 	argv[2] = buf;
@@ -209,17 +209,28 @@ int dumpe2fs(const char *device, struct dump2fs_data *data)
 	return 0;
 }
 
-int e2fsck(const char *device)
+int e2fsck(const char *device, int flags)
 {
-	char *arg[4];
+	char *arg[5];
+	int i = 0;
+	int ret;
 
-	arg[0] = "e2fsck";
-	arg[1] = "-fp";
-	arg[2] = (char *)device;
-	arg[3] = NULL;
+	arg[i++] = "e2fsck";
+	if (flags & E2FSCK_PREEN)
+		arg[i++] = "-p";
+	if (flags & E2FSCK_FORCE)
+		arg[i++] = "-f";
+	arg[i++] = (char *)device;
+	arg[i++] = NULL;
 
-	if (run_prg(arg))
+	if (run_prg_rc(arg, &ret))
 		return SYSEXIT_FSCK;
 
+	/* exit code < 4 is OK, see man e2fsck */
+	if (ret >= 4) {
+		ploop_err(0, "e2fsck failed (exit code %d)\n", ret);
+		return SYSEXIT_FSCK;
+	}
+
 	return 0;
 }
