@@ -44,11 +44,11 @@
 #define OD_ALLOW_DIRTY	0x1
 #define OD_OFFLINE	0x2
 
-/* fsck mode flags */
-#define FSCK_FORCE	0x01
-#define FSCK_HARDFORCE	0x02
-#define FSCK_DROPINUSE	0x04
-#define FSCK_CHECK	0x08
+/* flags for ploop_check() */
+#define CHECK_FORCE	0x01
+#define CHECK_HARDFORCE	0x02
+#define CHECK_DROPINUSE	0x04
+#define CHECK_DETAILED	0x08
 
 /* GPT */
 #define GPT_HEADER_SIZE		1
@@ -175,6 +175,12 @@ enum {
 	PLOOP_MERGE_WITH_PARENT = 1,
 };
 
+/* flags for e2fsck() */
+enum e2fsck_flags {
+	E2FSCK_PREEN	= 1 << 0, /* -p */
+	E2FSCK_FORCE	= 1 << 1, /* -f */
+};
+
 /* Mark lib functions used by ploop tools */
 #define PL_EXT __attribute__ ((visibility("default")))
 
@@ -222,6 +228,8 @@ int extend_delta_array(struct delta_array * p, char * path, int rw, int od_flags
 void close_delta(struct delta *delta);
 int open_delta(struct delta * delta, const char * path, int rw, int od_flags);
 int open_delta_simple(struct delta * delta, const char * path, int rw, int od_flags);
+int change_delta_version(struct delta *delta, int version);
+int change_delta_flags(struct delta * delta, __u32 flags);
 int dirty_delta(struct delta * delta);
 int clear_delta(struct delta * delta);
 int read_size_from_image(const char *img_name, int raw, off_t * res);
@@ -259,7 +267,7 @@ struct relocmap *relocmap_alloc(int n);
 struct ploop_relocblks_ctl;
 int relocmap2relocblks(struct relocmap *relocmap, int lvl, __u32 a_h, __u32 n_scanned,
 			struct ploop_relocblks_ctl **relocblks_pp);
-PL_EXT int ploop_fsck(char *img, int flags, int ro, int verbose, __u32 *blocksize_p);
+PL_EXT int ploop_check(char *img, int flags, int ro, int verbose, __u32 *blocksize_p);
 /* Logging */
 int ploop_get_log_level(void);
 void ploop_log(int level, const char *format, ...)
@@ -298,6 +306,7 @@ PL_EXT int ploop_getdevice(int *minor);
 struct ploop_disk_images_data *alloc_diskdescriptor(void);
 void get_disk_descriptor_fname(struct ploop_disk_images_data *di, char *buf, int size);
 void get_disk_descriptor_lock_fname(struct ploop_disk_images_data *di, char *out, int size);
+int find_image_idx_by_guid(struct ploop_disk_images_data *di, const char *guid);
 int ploop_find_dev_by_uuid(struct ploop_disk_images_data *di, int check_state, char *out, int len);
 int sys_fallocate(int fd, int mode, off_t offset, off_t len);
 int sys_syncfs(int fd);
@@ -342,7 +351,7 @@ int make_fs(const char *device, const char *fstype, unsigned int fsblocksize);
 void tune_fs(const char *target, const char *device, unsigned long long size);
 int resize_fs(const char *device, off_t blocks);
 int dumpe2fs(const char *device, struct dump2fs_data *data);
-int e2fsck(const char *device);
+int e2fsck(const char *device, int flags);
 int create_gpt_partition(const char *dev, off_t size, __u32 blocksize);
 int resize_gpt_partition(const char *devname, __u64 new_size);
 
@@ -361,12 +370,14 @@ PL_EXT int read_line(const char *path, char *nbuf, int len);
 int read_line_quiet(const char *path, char *nbuf, int len);
 int is_valid_blocksize(__u32 blocksize);
 int run_prg(char *const argv[]);
+int run_prg_rc(char *const argv[], int *rc);
 int p_memalign(void **memptr, size_t alignment, size_t size);
 PL_EXT int guidcmp(const char *p1, const char *p2);
 int auto_mount_image(struct ploop_disk_images_data *di,
 		struct ploop_mount_param *param);
 void free_mount_param(struct ploop_mount_param *param);
-int is_large_disk_supported(void);
+int check_and_restore_fmt_version(struct ploop_disk_images_data *di);
+int check_blockdev_size(unsigned long long sectors, __u32 blocksize, int version);
 
 // merge
 PL_EXT int get_delta_info(const char *device, struct merge_info *info);
@@ -374,4 +385,7 @@ PL_EXT int merge_image(const char *device, int start_level, int end_level, int r
 		char **images);
 int ploop_merge_snapshot_by_guid(struct ploop_disk_images_data *di, const char *guid, int merge_mode);
 
+PL_EXT int ploop_change_fmt_version(struct ploop_disk_images_data *di,
+		int new_version, int flags);
+
 #endif
