@@ -201,7 +201,7 @@ static int parse_xml(const char *basedir, xmlNode *root_node, struct ploop_disk_
 			file = get_element_txt(node);
 			if (file != NULL) {
 				if (basedir[0] != 0 && file[0] != '/')
-					snprintf(image, sizeof(image), "%s/%s", basedir, file);
+					snprintf(image, sizeof(image), "%s%s", basedir, file);
 				else
 					snprintf(image, sizeof(image), "%s", file);
 			}
@@ -268,7 +268,9 @@ void get_basedir(const char *fname, char *out, int len)
 
 	p = strrchr(out, '/');
 	if (p != NULL)
-		*p = 0;
+		*(++p) = '\0';
+	else
+		out[0] = '\0';
 }
 
 /* Convert to new format with constant TopGUID */
@@ -422,7 +424,7 @@ int ploop_store_diskdescriptor(const char *fname, struct ploop_disk_images_data
 	xmlTextWriterPtr writer = NULL;
 	xmlDocPtr doc = NULL;
 	char tmp[PATH_MAX];
-	char basedir[PATH_MAX] = "";
+	char basedir[PATH_MAX];
 
 	ploop_log(0, "Storing %s", fname);
 
@@ -430,8 +432,10 @@ int ploop_store_diskdescriptor(const char *fname, struct ploop_disk_images_data
 		return -1;
 
 	get_basedir(fname, tmp, sizeof(tmp));
+	if (tmp[0] == '\0')
+		strcpy(tmp, "./");
 
-	if (*tmp && realpath(tmp, basedir) == NULL) {
+	if (realpath(tmp, basedir) == NULL) {
 		ploop_err(errno, "Can't resolve %s", tmp);
 		return -1;
 	}
