@@ -38,11 +38,11 @@ extern int plooptool_snapshot_list(int argc, char **argv);
 static void usage_summary(void)
 {
 	fprintf(stderr, "Usage: ploop init -s SIZE [-f FORMAT] NEW_DELTA\n"
-			"       ploop mount [-rP] [-f raw] [-d DEVICE] BASE_DELTA [ ... TOP_DELTA]\n"
+			"       ploop mount [-r] [-f raw] [-d DEVICE] BASE_DELTA [ ... TOP_DELTA]\n"
 			"       ploop umount -d DEVICE\n"
 			"       ploop { delete | rm } -d DEVICE -l LEVEL\n"
 			"       ploop merge -d DEVICE [-l LEVEL[..TOP_LEVEL]]\n"
-			"       ploop fsck [-fcr] DELTA\n"
+			"       ploop check [-fcr] DELTA\n"
 			"       ploop getdev\n"
 			"       ploop resize -s SIZE BASE_DELTA\n"
 			"       ploop snapshot [-F] -d DEVICE NEW_DELTA\n"
@@ -57,16 +57,28 @@ static void usage_summary(void)
 
 static void usage_init(void)
 {
-	fprintf(stderr, "Usage: ploop init -s SIZE [-f FORMAT] [-t FSTYPE] [-b BLOCKSIZE]\n"
+	fprintf(stderr, "Usage: ploop init -s SIZE [-f FORMAT] [-v VERSION] [-t FSTYPE] [-b BLOCKSIZE]\n"
 			"		[-B FSBLOCKSIZE] DELTA\n"
-			"       SIZE := NUMBER[kmg]\n"
+			"       SIZE := NUMBER[KMGT]\n"
 			"       FORMAT := { raw | ploop1 }\n"
+			"       VERSION := { 1 | 2 }\n"
 			"       DELTA := path to new image file\n"
 			"       FSTYPE := make file system\n"
 			"       BLOCKSIZE := cluster block size in sectors\n"
 			"       FSBLOCKSIZE := file system block size in bytes\n");
 }
 
+static int parse_version_opt(const char *arg)
+{
+	if (!strcmp(arg, "1"))
+		return PLOOP_FMT_V1;
+	else if (!strcmp(arg, "2"))
+		return PLOOP_FMT_V2;
+
+	fprintf(stderr, "Invalid -v argument: %s\n", arg);
+	return -1;
+}
+
 static int plooptool_init(int argc, char **argv)
 {
 	int i, f, ret;
@@ -79,7 +91,7 @@ static int plooptool_init(int argc, char **argv)
 	while ((i = getopt(argc, argv, "s:b:B:f:t:v:")) != EOF) {
 		switch (i) {
 		case 's':
-			if (parse_size(optarg, &size_sec)) {
+			if (parse_size(optarg, &size_sec, "-s")) {
 				usage_init();
 				return SYSEXIT_PARAM;
 			}
@@ -116,15 +128,12 @@ static int plooptool_init(int argc, char **argv)
 			}
 			break;
 		case 'v':
-			if (!strcmp(optarg, "1"))
-				param.fmt_version = PLOOP_FMT_V1;
-			else if (!strcmp(optarg, "2"))
-				param.fmt_version = PLOOP_FMT_V2;
-			else {
-				fprintf(stderr, "Unknown ploop image version: %s\n",
-						optarg);
+			f = parse_version_opt(optarg);
+			if (f < 0) {
+				usage_init();
 				return SYSEXIT_PARAM;
 			}
+			param.fmt_version = f;
 			break;
 		default:
 			usage_init();
@@ -162,6 +171,7 @@ static void usage_mount(void)
 			"       MOUNT_OPTS := additional mount options, comma-separated\n"
 			"       *DELTA := path to image file\n"
 			"       -r     - mount images read-only\n"
+			"       -F     - run fsck on inner filesystem before mounting it\n"
 		);
 }
 
@@ -173,7 +183,7 @@ static int plooptool_mount(int argc, char **argv)
 	struct ploop_mount_param mountopts = {};
 	const char *component_name = NULL;
 
-	while ((i = getopt(argc, argv, "rf:d:m:t:u:o:b:c:")) != EOF) {
+	while ((i = getopt(argc, argv, "rFf:d:m:t:u:o:b:c:")) != EOF) {
 		switch (i) {
 		case 'd':
 			strncpy(mountopts.device, optarg, sizeof(mountopts.device)-1);
@@ -181,6 +191,9 @@ static int plooptool_mount(int argc, char **argv)
 		case 'r':
 			mountopts.ro = 1;
 			break;
+		case 'F':
+			mountopts.fsck = 1;
+			break;
 		case 'f':
 			f = parse_format_opt(optarg);
 			if (f < 0) {
@@ -775,7 +788,7 @@ static int plooptool_getdevice(int argc, char **argv)
 static void usage_resize(void)
 {
 	fprintf(stderr, "Usage: ploop resize -s NEW_SIZE DiskDescriptor.xml\n"
-			"       NEW_SIZE := NUMBER[kmg]\n");
+			"       NEW_SIZE := NUMBER[KMGT]\n");
 }
 
 static int plooptool_resize(int argc, char **argv)
@@ -789,7 +802,7 @@ static int plooptool_resize(int argc, char **argv)
 	while ((i = getopt(argc, argv, "s:b")) != EOF) {
 		switch (i) {
 		case 's':
-			if (parse_size(optarg, &new_size)) {
+			if (parse_size(optarg, &new_size, "-s")) {
 				usage_resize();
 				return SYSEXIT_PARAM;
 			}
@@ -828,8 +841,9 @@ static int plooptool_resize(int argc, char **argv)
 
 static void usage_convert(void)
 {
-	fprintf(stderr, "Usage: ploop convert -f FORMAT DiskDescriptor.xml\n"
+	fprintf(stderr, "Usage: ploop convert {-f FORMAT | -v VERSION} DiskDescriptor.xml\n"
 			"       FORMAT := { raw | preallocated }\n"
+			"       VERSION := { 1 | 2 }\n"
 			);
 }
 
@@ -838,12 +852,20 @@ static int plooptool_convert(int argc, char **argv)
 	int i, ret;
 	struct ploop_disk_images_data *di;
 	int mode = -1;
+	int version = -1;
 
-	while ((i = getopt(argc, argv, "f:")) != EOF) {
+	while ((i = getopt(argc, argv, "f:v:")) != EOF) {
 		switch (i) {
 		case 'f':
 			mode = parse_format_opt(optarg);
 			break;
+		case 'v':
+			version = parse_version_opt(optarg);
+			if (version < 0) {
+				 usage_convert();
+				 return SYSEXIT_PARAM;
+			}
+			break;
 		default:
 			usage_convert();
 			return SYSEXIT_PARAM;
@@ -853,7 +875,10 @@ static int plooptool_convert(int argc, char **argv)
 	argc -= optind;
 	argv += optind;
 
-	if (argc == 0 || mode == -1) {
+	if (argc == 0 ||
+		(mode == -1 && version == -1) ||
+		(mode != -1 && version != -1))
+	{
 		usage_convert();
 		return SYSEXIT_PARAM;
 	}
@@ -861,8 +886,10 @@ static int plooptool_convert(int argc, char **argv)
 	ret = read_dd(&di, argv[0]);
 	if (ret)
 		return ret;
-
-	ret = ploop_convert_image(di, mode, 0);
+	if (mode != -1)
+		ret = ploop_convert_image(di, mode, 0);
+	else if (version != -1)
+		ret = ploop_change_fmt_version(di, version, 0);
 
 	ploop_free_diskdescriptor(di);
 
